Documentation
¶
Index ¶
Constants ¶
const NotFound string = "NOT_FOUND"
const Success string = "SUCCESS"
Variables ¶
This section is empty.
Functions ¶
func NewUserController ¶
func NewUserController() *userController
NewUserController is the constructor of the object
func SetupRouter ¶
SetupRouter determine all the routes for this service
Types ¶
type ApiErrorResponse ¶
type ApiErrorResponse struct {
Error string `json:"error"`
}
type HealthController ¶
type HealthController struct {
}
HealthController who handle health check
func (HealthController) HealthCheck ¶
func (h HealthController) HealthCheck(c *gin.Context)
HealthCheck return the Status of the current app @Summary Health check endpoint @Description health check endpoint to know if the service is up @Tags healthcheck @Produce json @Success 200 {object} api.healthCheck @Router /health [get]
Click to show internal directories.
Click to hide internal directories.